summaryrefslogtreecommitdiff
path: root/hints
diff options
context:
space:
mode:
authorRainer Orth <ro@TechFak.Uni-Bielefeld.DE>2002-07-15 21:23:54 +0200
committerJarkko Hietaniemi <jhi@iki.fi>2002-07-15 16:26:55 +0000
commit993a793cf0b1da8e06050ac82b73e14c9a6bab6d (patch)
tree9e2a530145aace96572dae34c067ab6336da3871 /hints
parentb907dc6df5598c65ac49c95722cc559b8745a323 (diff)
downloadperl-993a793cf0b1da8e06050ac82b73e14c9a6bab6d.tar.gz
[ID 20020715.009] perl 5.8.0 RC3 incorrectly tests gcc version on Tru64 UNIX V4.0F
Message-Id: <5.8.0_22255_1026753561@rimsky> (also raise the gcc minimum to 2.95.3) p4raw-id: //depot/perl@17554
Diffstat (limited to 'hints')
-rw-r--r--hints/dec_osf.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/hints/dec_osf.sh b/hints/dec_osf.sh
index 7c3569f70c..b3872fac12 100644
--- a/hints/dec_osf.sh
+++ b/hints/dec_osf.sh
@@ -73,12 +73,12 @@ gcc) if [ "X$gccversion" = "X" ]; then
# Done too late in Configure if hinted
gccversion=`$cc --version | sed 's/.*(GCC) *//'`
fi
- set $gcc_version
- if test "$1" -lt 2 -o \( "$1" -eq 2 -a \( "$2" -lt 95 -o \( "$2" -eq 95 -a "$3" -lt 2 \) \) \); then
+ set $gccversion
+ if test "$1" -lt 2 -o \( "$1" -eq 2 -a \( "$2" -lt 95 -o \( "$2" -eq 95 -a "$3" -lt 3 \) \) \); then
cat >&4 <<EOF
*** Your cc seems to be gcc and its version ($gcc_version) seems to be
*** less than 2.95.2. This is not a good idea since old versions of gcc
*** are known to produce buggy code when compiling Perl (and no doubt for
*** other programs, too).
***
@@ -73,12 +73,12 @@ gcc) if [ "X$gccversion" = "X" ]; then
cat >&4 <<EOF
-*** Your cc seems to be gcc and its version ($gcc_version) seems to be
-*** less than 2.95.2. This is not a good idea since old versions of gcc
+*** Your cc seems to be gcc and its version ($gccversion) seems to be
+*** less than 2.95.3. This is not a good idea since old versions of gcc
*** are known to produce buggy code when compiling Perl (and no doubt for
*** other programs, too).